@@ -26,7 +26,6 @@
 #include <ksgrd/SensorManager.h>
 
 #include <QEventLoop>
-#include <QTimer>
 
 // TODO instantiate multiple instances with args for which host to use
 
@@ -39,11 +38,7 @@ KSGRDIface::KSGRDIface(QObject *parent, const QVariantList &args)
         m_subsystems[id] = new SensorContainer(id, KSGRD::SensorMgr->translateSensorPath(id), this);
     };
     registerSubsystem("acpi");
-    registerSubsystem("cpu");
-    registerSubsystem("disk");
     registerSubsystem("lmsensors");
-    registerSubsystem("mem");
-    registerSubsystem("partitions");
     registerSubsystem("uptime");
     registerSubsystem("system");
 
@@ -67,7 +62,6 @@ KSGRDIface::KSGRDIface(QObject *parent, const QVariantList &args)
         }
     });
     e.exec();
-    addAggregateSensors();
 }
 
 KSGRDIface::~KSGRDIface()
@@ -145,7 +139,6 @@ void KSGRDIface::onSensorMetaDataRetrieved(int id, const QList<QByteArray> &answ
     }
 
     sensor->setName(sensorName);
-    sensor->setShortName(shortNameFor(key));
     sensor->setMin(min.toDouble());
     sensor->setMax(max.toDouble());
     sensor->setUnit(unitFromString(unit));
@@ -303,86 +296,6 @@ void KSGRDIface::answerReceived(int id, const QList<QByteArray> &answer)
     onSensorUpdated(id, answer);
 }
 
-void KSGRDIface::addAggregateSensors()
-{
-    auto diskAll = new SensorObject("all", i18nc("@title All Disks", "All"), m_subsystems["disk"]);
-    auto sensor = new AggregateSensor(diskAll, "read", i18nc("@title", "Disk Read Accesses"));
-    sensor->setShortName(i18nc("@title Disk Read Accesses", "Read"));
-    // TODO: This regex is not exhaustive as it doesn't consider things that aren't treated as sdX devices.
-    //       However, we do not simply want to match disk/* as that would include duplicate devices.
-    sensor->setMatchSensors(QRegularExpression("^sd[a-z]+[0-9]+_[^/]*/Rate$"), QStringLiteral("rblk"));
-    sensor->setDescription(i18nc("@info", "Read accesses across all disk devices"));
-    sensor->setUnit(KSysGuard::UnitKiloByteRate);
-
-    sensor = new AggregateSensor(diskAll, "write", i18nc("@title", "Disk Write Accesses"));
-    sensor->setShortName(i18nc("@title Disk Write Accesses", "Write"));
-    // TODO: See above.
-    sensor->setMatchSensors(QRegularExpression("^sd[a-z]+[0-9]+_[^/]*/Rate$"), QStringLiteral("wblk"));
-    sensor->setDescription(i18nc("@info", "Write accesses across all disk devices"));
-    sensor->setUnit(KSysGuard::UnitKiloByteRate);
-
-    auto memPhysical = m_subsystems["mem"]->object("physical");
-    Q_ASSERT(memPhysical);
-    if (!memPhysical) {
-        return;
-    }
-
-    PercentageSensor *appLevel = new PercentageSensor(memPhysical, "applicationlevel", i18nc("@title", "Application Memory Percentage"));
-    appLevel->setShortName(i18nc("@title Application Memory Percentage", "Application"));
-    appLevel->setBaseSensor(memPhysical->sensor("application"));
-    appLevel->setDescription(i18nc("@info", "Percentage of memory taken by applications."));
-
-    PercentageSensor *bufLevel = new PercentageSensor(memPhysical, "buflevel", i18nc("@title", "Buffer Memory Percentage"));
-    bufLevel->setShortName(i18nc("@title Buffer Memory Percentage", "Buffer"));
-    bufLevel->setBaseSensor(memPhysical->sensor("buf"));
-    bufLevel->setDescription(i18nc("@info", "Percentage of memory taken by the buffer."));
-
-    PercentageSensor *cacheLevel = new PercentageSensor(memPhysical, "cachelevel", i18nc("@title", "Cache Memory Percentage"));
-    cacheLevel->setShortName(i18nc("@title Cache Memory Percentage", "Cache"));
-    cacheLevel->setBaseSensor(memPhysical->sensor("cached"));
-    cacheLevel->setDescription(i18nc("@info", "Percentage of memory taken by the cache."));
-
-    PercentageSensor *freeLevel = new PercentageSensor(memPhysical, "freelevel", i18nc("@title", "Free Memory Percentage"));
-    freeLevel->setShortName(i18nc("@title Free Memory Percentage", "Free"));
-    freeLevel->setBaseSensor(memPhysical->sensor("free"));
-    freeLevel->setDescription(i18nc("@info", "Percentage of free memory."));
-
-    PercentageSensor *usedLevel = new PercentageSensor(memPhysical, "usedlevel", i18nc("@title", "Used Memory Percentage"));
-    usedLevel->setShortName(i18nc("@title Used Memory Percentage", "Used"));
-    usedLevel->setBaseSensor(memPhysical->sensor("used"));
-    usedLevel->setDescription(i18nc("@info", "Percentage of used memory."));
-
-    PercentageSensor *availableLevel = new PercentageSensor(memPhysical, "availablelevel", i18nc("@title", "Available Memory Percentage"));
-    availableLevel->setShortName(i18nc("@title Available Memory Percentage", "Available"));
-    availableLevel->setBaseSensor(memPhysical->sensor("available"));
-    availableLevel->setDescription(i18nc("@info", "Percentage of available memory."));
-
-    PercentageSensor *allocatedLevel = new PercentageSensor(memPhysical, "allocatedlevel", i18nc("@title", "Allocated Memory Percentage"));
-    allocatedLevel->setShortName(i18nc("@title Allocated Memory Percentage", "Allocated"));
-    allocatedLevel->setBaseSensor(memPhysical->sensor("allocated"));
-    allocatedLevel->setDescription(i18nc("@info", "Percentage of allocated memory."));
-}
-
-QString KSGRDIface::shortNameFor(const QString &key)
-{
-    // TODO: This is pretty ugly, but it is really hard to add this information to ksysguardd.
-    // So for now, we just map sensor ids to short names and return that.
-
-    static QHash<QString, QString> shortNames = {
-        { QStringLiteral("cpu/system/TotalLoad"), i18nc("@title Total CPU Usage", "Usage") },
-        { QStringLiteral("mem/physical/used"), i18nc("@title Total Memory Usage", "Total Used") },
-        { QStringLiteral("mem/physical/cached"), i18nc("@title Cached Memory Usage", "Cached") },
-        { QStringLiteral("mem/physical/free"), i18nc("@title Free Memory Amount", "Free") },
-        { QStringLiteral("mem/physical/available"), i18nc("@title Available Memory Amount", "Available") },
-        { QStringLiteral("mem/physical/application"), i18nc("@title Application Memory Usage", "Application") },
-        { QStringLiteral("mem/physical/buf"), i18nc("@title Buffer Memory Usage", "Buffer") },
-        { QStringLiteral("cpu/system/processors"), i18nc("@title Number of Processors", "Processors") },
-        { QStringLiteral("cpu/system/cores"), i18nc("@title Number of Cores", "Cores") },
-    };
-
-    return shortNames.value(key, QString {});
-}
-
 K_PLUGIN_CLASS_WITH_JSON(KSGRDIface, "metadata.json")
 
 #include "ksgrdiface.moc"
